@@ -196,7 +196,8 @@ def attach_snapshot(snap, key_pair=None, security_groups='', inst=None,
     newly created temporary instance for `key_pair` and with
     `security_groups`."""
 
-    wait_for(snap, '100%', limit=10 * 60)
+    wait_for(snap, '100%', limit=60 * 60)
+    assert snap.status == 'completed'
 
     def force_snap_attach(inst, snap):
         """Iterate over devices until successful attachment."""
